# KungFu - A GStreamer based DVD ripper
# Copyright (C) 2006 Jason Gerard DeRose <jderose@jasonderose.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

from os import path
import kf_state


class Source(object):
	def __init__(self, device, prefix):
		self._device = device
		self._prefix = prefix
		
	def _get_device(self):
		return self._device
		
	device = property(_get_device)
	
	def _get_prefix(self):
		return self._prefix
		
	prefix = property(_get_prefix)



class Title(object):
	def __init__(self, model, path, device, title, prefix):
		self._map = {}
		self._model = model
		self._path = path
		self._outfile = None
		self.device = device
		self.title = title
		self.prefix = prefix

	def get(self, key):
		if key in self._map:
			return self._map[key]
		else:
			value = kf_state.get(key)
			self._map[key] = value
			return value
	
	def set(self, key, value):
		self._map[key] = value
		kf_state.set(key, value)
	
	
	def _set_rip(self, rip):
		self._model[self._path][1] = rip
			
	def _get_rip(self):
		return self._model[self._path][1]
		
	rip = property(_get_rip, _set_rip)


	def _set_text(self, value):
		self._model[self._path][2] = value
			
	def _get_text(self):
		return self._model[self._path][2]
		
	text = property(_get_text, _set_text)


	def _get_outfile(self):
		if self._outfile == None:
			folder = kf_state.get('output_folder')
			name = '%s_%02d.ogg' % (self.prefix, self.title)
			self._outfile = path.join(folder, name.lower())
		return self._outfile
		
	def _set_outfile(self, outfile):
		self._outfile = outfile
		kf_state.set('output_folder', path.dirname(outfile))
		
	outfile = property(_get_outfile, _set_outfile)
